-
- All Implemented Interfaces:
-
org.bitcoindevkit.Disposable
public final class ConfirmationBlockTime implements Disposable
Represents the confirmation block and time of a transaction.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public classConfirmationBlockTime.Companion
-
Field Summary
Fields Modifier and Type Field Description private BlockIdblockIdprivate ULongconfirmationTime
-
Constructor Summary
Constructors Constructor Description ConfirmationBlockTime(BlockId blockId, ULong confirmationTime)
-
Method Summary
Modifier and Type Method Description final BlockIdgetBlockId()The anchor block. final UnitsetBlockId(BlockId blockId)The anchor block. final ULonggetConfirmationTime()The confirmation time of the transaction being anchored. final UnitsetConfirmationTime(ULong confirmationTime)The confirmation time of the transaction being anchored. Unitdestroy()-
-
Method Detail
-
getBlockId
final BlockId getBlockId()
The anchor block.
-
setBlockId
final Unit setBlockId(BlockId blockId)
The anchor block.
-
getConfirmationTime
final ULong getConfirmationTime()
The confirmation time of the transaction being anchored.
-
setConfirmationTime
final Unit setConfirmationTime(ULong confirmationTime)
The confirmation time of the transaction being anchored.
-
-
-
-