-
public final class ControlBlock
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public classControlBlock.Companion
-
Field Summary
Fields Modifier and Type Field Description private ByteArrayinternalKeyprivate List<String>merkleBranchprivate UByteoutputKeyParityprivate UByteleafVersion
-
Method Summary
Modifier and Type Method Description final ByteArraygetInternalKey()The internal key. final UnitsetInternalKey(ByteArray internalKey)The internal key. final List<String>getMerkleBranch()The merkle proof of a script associated with this leaf. final UnitsetMerkleBranch(List<String> merkleBranch)The merkle proof of a script associated with this leaf. final UBytegetOutputKeyParity()The parity of the output key (NOT THE INTERNAL KEY WHICH IS ALWAYS XONLY). final UnitsetOutputKeyParity(UByte outputKeyParity)The parity of the output key (NOT THE INTERNAL KEY WHICH IS ALWAYS XONLY). final UBytegetLeafVersion()The tapleaf version. final UnitsetLeafVersion(UByte leafVersion)The tapleaf version. -
-
Method Detail
-
getInternalKey
final ByteArray getInternalKey()
The internal key.
-
setInternalKey
final Unit setInternalKey(ByteArray internalKey)
The internal key.
-
getMerkleBranch
final List<String> getMerkleBranch()
The merkle proof of a script associated with this leaf.
-
setMerkleBranch
final Unit setMerkleBranch(List<String> merkleBranch)
The merkle proof of a script associated with this leaf.
-
getOutputKeyParity
final UByte getOutputKeyParity()
The parity of the output key (NOT THE INTERNAL KEY WHICH IS ALWAYS XONLY).
-
setOutputKeyParity
final Unit setOutputKeyParity(UByte outputKeyParity)
The parity of the output key (NOT THE INTERNAL KEY WHICH IS ALWAYS XONLY).
-
getLeafVersion
final UByte getLeafVersion()
The tapleaf version.
-
setLeafVersion
final Unit setLeafVersion(UByte leafVersion)
The tapleaf version.
-
-
-
-