Package 

Class DerivationPath

    • Constructor Summary

      Constructors 
      Constructor Description
      DerivationPath(Pointer pointer)
      DerivationPath(NoPointer noPointer) This constructor can be used to instantiate a fake object.
      DerivationPath(String path) Parse a string as a BIP-32 derivation path.
    • Method Summary

      Modifier and Type Method Description
      Unit destroy()
      Unit close()
      final Pointer uniffiClonePointer()
      Boolean isEmpty() Returns true if the derivation path is empty
      Boolean isMaster() Returns whether derivation path represents master key (i.e.
      ULong len() Returns length of the derivation path
      String toString()
      • Methods inherited from class java.lang.Object

        clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
    • Constructor Detail

      • DerivationPath

        DerivationPath(Pointer pointer)
      • DerivationPath

        DerivationPath(NoPointer noPointer)
        This constructor can be used to instantiate a fake object.
      • DerivationPath

        DerivationPath(String path)
        Parse a string as a BIP-32 derivation path.