Package 

Interface DerivationPathInterface

    • Method Summary

      Modifier and Type Method Description
      abstract DerivationPath child(ChildNumber childNumber) Create a new DerivationPath that is a child of this one.
      abstract DerivationPath extend(DerivationPath other) Concatenate self with path and return the resulting new path.
      abstract Boolean isEmpty() Returns true if the derivation path is empty
      abstract Boolean isMaster() Returns whether derivation path represents master key (i.e.
      abstract ULong len() Returns length of the derivation path
      abstract List<UInt> toU32Vec() Returns the derivation path as a vector of u32 integers.
      • Methods inherited from class java.lang.Object

        clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
    • Method Detail

      • isEmpty

         abstract Boolean isEmpty()

        Returns true if the derivation path is empty

      • isMaster

         abstract Boolean isMaster()

        Returns whether derivation path represents master key (i.e. it's length is empty). True for m path.

      • len

         abstract ULong len()

        Returns length of the derivation path

      • toU32Vec

         abstract List<UInt> toU32Vec()

        Returns the derivation path as a vector of u32 integers. Unhardened elements are copied as is. 0x80000000 is added to the hardened elements.