-
- All Implemented Interfaces:
-
java.lang.AutoCloseable,org.bitcoindevkit.DescriptorInterface,org.bitcoindevkit.Disposable
public class Descriptor implements Disposable, AutoCloseable, DescriptorInterface
An expression of how to derive output scripts: https://github.com/bitcoin/bitcoin/blob/master/doc/descriptors.md
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public classDescriptor.Companion
-
Constructor Summary
Constructors Constructor Description Descriptor(String descriptor, Network network)Parse a string as a descriptor for the given network.
-
Method Summary
Modifier and Type Method Description Unitdestroy()Unitclose()AddressderiveAddress(UInt index, Network network)DescriptorTypedescType()DescriptorIddescriptorId()A unique identifier for the descriptor. BooleanisMultipath()Does this descriptor contain paths: https://github.com/bitcoin/bips/blob/master/bip-0389. ULongmaxWeightToSatisfy()Computes an upper bound on the difference between a non-satisfied TxIn'ssegwit_weightand a satisfiedTxIn'ssegwit_weight.List<Descriptor>toSingleDescriptors()Return descriptors for all valid paths. StringtoStringWithSecret()Dangerously convert the descriptor to a string. StringtoString()-
-
Method Detail
-
deriveAddress
Address deriveAddress(UInt index, Network network)
-
descType
DescriptorType descType()
-
descriptorId
DescriptorId descriptorId()
A unique identifier for the descriptor.
-
isMultipath
Boolean isMultipath()
Does this descriptor contain paths: https://github.com/bitcoin/bips/blob/master/bip-0389.mediawiki
-
maxWeightToSatisfy
ULong maxWeightToSatisfy()
Computes an upper bound on the difference between a non-satisfied
TxIn'ssegwit_weightand a satisfiedTxIn'ssegwit_weight.
-
toSingleDescriptors
List<Descriptor> toSingleDescriptors()
Return descriptors for all valid paths.
-
toStringWithSecret
String toStringWithSecret()
Dangerously convert the descriptor to a string.
-
-
-
-