-
public interface DescriptorInterfaceAn expression of how to derive output scripts: https://github.com/bitcoin/bitcoin/blob/master/doc/descriptors.md
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public classDescriptorInterface.Companion
-
Method Summary
Modifier and Type Method Description abstract AddressderiveAddress(UInt index, Network network)abstract DescriptorTypedescType()abstract DescriptorIddescriptorId()A unique identifier for the descriptor. abstract BooleanisMultipath()Does this descriptor contain paths: https://github.com/bitcoin/bips/blob/master/bip-0389. abstract ULongmaxWeightToSatisfy()Computes an upper bound on the difference between a non-satisfied TxIn'ssegwit_weightand a satisfiedTxIn'ssegwit_weight.abstract List<Descriptor>toSingleDescriptors()Return descriptors for all valid paths. abstract StringtoStringWithSecret()Dangerously convert the descriptor to a string. -
-
Method Detail
-
deriveAddress
abstract Address deriveAddress(UInt index, Network network)
-
descType
abstract DescriptorType descType()
-
descriptorId
abstract DescriptorId descriptorId()
A unique identifier for the descriptor.
-
isMultipath
abstract Boolean isMultipath()
Does this descriptor contain paths: https://github.com/bitcoin/bips/blob/master/bip-0389.mediawiki
-
maxWeightToSatisfy
abstract ULong maxWeightToSatisfy()
Computes an upper bound on the difference between a non-satisfied
TxIn'ssegwit_weightand a satisfiedTxIn'ssegwit_weight.
-
toSingleDescriptors
abstract List<Descriptor> toSingleDescriptors()
Return descriptors for all valid paths.
-
toStringWithSecret
abstract String toStringWithSecret()
Dangerously convert the descriptor to a string.
-
-
-
-