-
- All Implemented Interfaces:
-
java.lang.AutoCloseable,org.bitcoindevkit.DescriptorPublicKeyInterface,org.bitcoindevkit.Disposable
public class DescriptorPublicKey implements Disposable, AutoCloseable, DescriptorPublicKeyInterface
A descriptor public key.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public classDescriptorPublicKey.Companion
-
Method Summary
Modifier and Type Method Description Unitdestroy()Unitclose()DescriptorPublicKeyderive(DerivationPath path)Derive the descriptor public key at the given derivation path. DescriptorPublicKeyextend(DerivationPath path)Extend the descriptor public key by the given derivation path. BooleanisMultipath()Whether or not this key has multiple derivation paths. StringmasterFingerprint()The fingerprint of the master key associated with this key, 0x00000000if none.StringtoString()-
-
Method Detail
-
derive
DescriptorPublicKey derive(DerivationPath path)
Derive the descriptor public key at the given derivation path.
-
extend
DescriptorPublicKey extend(DerivationPath path)
Extend the descriptor public key by the given derivation path.
-
isMultipath
Boolean isMultipath()
Whether or not this key has multiple derivation paths.
-
masterFingerprint
String masterFingerprint()
The fingerprint of the master key associated with this key,
0x00000000if none.
-
-
-
-