-
public interface DescriptorPublicKeyInterfaceA descriptor public key.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public classDescriptorPublicKeyInterface.Companion
-
Method Summary
Modifier and Type Method Description abstract DescriptorPublicKeyderive(DerivationPath path)Derive the descriptor public key at the given derivation path. abstract DescriptorPublicKeyextend(DerivationPath path)Extend the descriptor public key by the given derivation path. abstract BooleanisMultipath()Whether or not this key has multiple derivation paths. abstract StringmasterFingerprint()The fingerprint of the master key associated with this key, 0x00000000if none.-
-
Method Detail
-
derive
abstract DescriptorPublicKey derive(DerivationPath path)
Derive the descriptor public key at the given derivation path.
-
extend
abstract DescriptorPublicKey extend(DerivationPath path)
Extend the descriptor public key by the given derivation path.
-
isMultipath
abstract Boolean isMultipath()
Whether or not this key has multiple derivation paths.
-
masterFingerprint
abstract String masterFingerprint()
The fingerprint of the master key associated with this key,
0x00000000if none.
-
-
-
-