-
- All Implemented Interfaces:
-
java.lang.AutoCloseable,org.bitcoindevkit.DescriptorSecretKeyInterface,org.bitcoindevkit.Disposable
public class DescriptorSecretKey implements Disposable, AutoCloseable, DescriptorSecretKeyInterface
A descriptor containing secret data.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public classDescriptorSecretKey.Companion
-
Constructor Summary
Constructors Constructor Description DescriptorSecretKey(Network network, Mnemonic mnemonic, String password)Construct a secret descriptor using a mnemonic.
-
Method Summary
Modifier and Type Method Description Unitdestroy()Unitclose()DescriptorPublicKeyasPublic()Return the descriptor public key corresponding to this secret. DescriptorSecretKeyderive(DerivationPath path)Derive a descriptor secret key at a given derivation path. DescriptorSecretKeyextend(DerivationPath path)Extend the descriptor secret key by the derivation path. ByteArraysecretBytes()Return the bytes of this descriptor secret key. StringtoString()-
-
Method Detail
-
asPublic
DescriptorPublicKey asPublic()
Return the descriptor public key corresponding to this secret.
-
derive
DescriptorSecretKey derive(DerivationPath path)
Derive a descriptor secret key at a given derivation path.
-
extend
DescriptorSecretKey extend(DerivationPath path)
Extend the descriptor secret key by the derivation path.
-
secretBytes
ByteArray secretBytes()
Return the bytes of this descriptor secret key.
-
-
-
-