-
public interface DescriptorSecretKeyInterfaceA descriptor containing secret data.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public classDescriptorSecretKeyInterface.Companion
-
Method Summary
Modifier and Type Method Description abstract DescriptorPublicKeyasPublic()Return the descriptor public key corresponding to this secret. abstract DescriptorSecretKeyderive(DerivationPath path)Derive a descriptor secret key at a given derivation path. abstract DescriptorSecretKeyextend(DerivationPath path)Extend the descriptor secret key by the derivation path. abstract ByteArraysecretBytes()Return the bytes of this descriptor secret key. -
-
Method Detail
-
asPublic
abstract DescriptorPublicKey asPublic()
Return the descriptor public key corresponding to this secret.
-
derive
abstract DescriptorSecretKey derive(DerivationPath path)
Derive a descriptor secret key at a given derivation path.
-
extend
abstract DescriptorSecretKey extend(DerivationPath path)
Extend the descriptor secret key by the derivation path.
-
secretBytes
abstract ByteArray secretBytes()
Return the bytes of this descriptor secret key.
-
-
-
-