-
public interface EsploraClientInterfaceWrapper around an esplora_client::BlockingClient which includes an internal in-memory transaction cache to avoid re-fetching already downloaded transactions.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public classEsploraClientInterface.Companion
-
Method Summary
Modifier and Type Method Description abstract Unitbroadcast(Transaction transaction)Broadcast a `Transaction` to Esplora. abstract UpdatefullScan(FullScanRequest request, ULong stopGap, ULong parallelRequests)Scan keychain scripts for transactions against Esplora, returning an update that can be applied to the receiving structures. abstract List<Tx>getAddressTxs(Address address, Txid lastSeen)Get transaction history for the specified address, sorted with newest first. abstract BlockgetBlockByHash(BlockHash blockHash)Get a Block given a particular BlockHash. abstract BlockHashgetBlockHash(UInt blockHeight)Get the `BlockHash` of a specific block height. abstract Map<UShort, Double>getFeeEstimates()Get a map where the key is the confirmation target (in number of blocks) and the value is the estimated feerate (in sat/vB). abstract HeadergetHeaderByHash(BlockHash blockHash)Get a Headergiven a particular block hash.abstract UIntgetHeight()Get the height of the current blockchain tip. abstract MerkleProofgetMerkleProof(Txid txid)Get a merkle inclusion proof for a `Transaction` with the given `Txid`. abstract OutputStatusgetOutputStatus(Txid txid, ULong vout)Get the spending status of an output given a Txidand the output index.abstract BlockHashgetTipHash()Get the BlockHashof the current blockchain tip.abstract TransactiongetTx(Txid txid)Get a `Transaction` option given its `Txid`. abstract TxgetTxInfo(Txid txid)Get transaction info given its `Txid`. abstract TransactiongetTxNoOpt(Txid txid)Get a Transactiongiven itsTxid.abstract TxStatusgetTxStatus(Txid txid)Get the status of a `Transaction` given its `Txid`. abstract TxidgetTxidAtBlockIndex(BlockHash blockHash, ULong index)Get a Txidof a transaction given its index in a block with a given hash.abstract Updatesync(SyncRequest request, ULong parallelRequests)Sync a set of scripts, txids, and/or outpoints against Esplora. -
-
Method Detail
-
broadcast
abstract Unit broadcast(Transaction transaction)
Broadcast a `Transaction` to Esplora.
-
fullScan
abstract Update fullScan(FullScanRequest request, ULong stopGap, ULong parallelRequests)
Scan keychain scripts for transactions against Esplora, returning an update that can be applied to the receiving structures.
requestprovides the data required to perform a script-pubkey-based full scan (see `FullScanRequest`). The full scan for each keychain (K) stops after a gap ofstop_gapscript pubkeys with no associated transactions.parallel_requestsspecifies the maximum number of HTTP requests to make in parallel.
-
getAddressTxs
abstract List<Tx> getAddressTxs(Address address, Txid lastSeen)
Get transaction history for the specified address, sorted with newest first.
Returns up to 50 mempool transactions plus the first 25 confirmed transactions. More can be requested by specifying the last txid seen by the previous query.
-
getBlockByHash
abstract Block getBlockByHash(BlockHash blockHash)
Get a Block given a particular BlockHash.
-
getBlockHash
abstract BlockHash getBlockHash(UInt blockHeight)
Get the `BlockHash` of a specific block height.
-
getFeeEstimates
abstract Map<UShort, Double> getFeeEstimates()
Get a map where the key is the confirmation target (in number of blocks) and the value is the estimated feerate (in sat/vB).
-
getHeaderByHash
abstract Header getHeaderByHash(BlockHash blockHash)
Get a
Headergiven a particular block hash.
-
getMerkleProof
abstract MerkleProof getMerkleProof(Txid txid)
Get a merkle inclusion proof for a `Transaction` with the given `Txid`.
-
getOutputStatus
abstract OutputStatus getOutputStatus(Txid txid, ULong vout)
Get the spending status of an output given a
Txidand the output index.
-
getTipHash
abstract BlockHash getTipHash()
Get the
BlockHashof the current blockchain tip.
-
getTx
abstract Transaction getTx(Txid txid)
Get a `Transaction` option given its `Txid`.
-
getTxNoOpt
abstract Transaction getTxNoOpt(Txid txid)
Get a
Transactiongiven itsTxid.
-
getTxStatus
abstract TxStatus getTxStatus(Txid txid)
Get the status of a `Transaction` given its `Txid`.
-
getTxidAtBlockIndex
abstract Txid getTxidAtBlockIndex(BlockHash blockHash, ULong index)
Get a
Txidof a transaction given its index in a block with a given hash.
-
sync
abstract Update sync(SyncRequest request, ULong parallelRequests)
Sync a set of scripts, txids, and/or outpoints against Esplora.
requestprovides the data required to perform a script-pubkey-based sync (see `SyncRequest`).parallel_requestsspecifies the maximum number of HTTP requests to make in parallel.
-
-
-
-