Package 

Class HashableOutPoint

  • All Implemented Interfaces:
    java.lang.AutoCloseable , org.bitcoindevkit.Disposable , org.bitcoindevkit.HashableOutPointInterface

    
    public class HashableOutPoint
     implements Disposable, AutoCloseable, HashableOutPointInterface
                        

    An `OutPoint` used as a key in a hash map.

    Due to limitations in generating the foreign language bindings, we cannot use `OutPoint` as a key for hash maps.

    • Constructor Detail

      • HashableOutPoint

        HashableOutPoint(Pointer pointer)
      • HashableOutPoint

        HashableOutPoint(NoPointer noPointer)
        This constructor can be used to instantiate a fake object.
      • HashableOutPoint

        HashableOutPoint(OutPoint outpoint)
        Create a key for a key-value store from an `OutPoint`