-
public interface HashableOutPointInterfaceAn `OutPoint` used as a key in a hash map.
Due to limitations in generating the foreign language bindings, we cannot use `OutPoint` as a key for hash maps.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public classHashableOutPointInterface.Companion
-