Package 

Class Info


  • 
    public class Info
    
                        

    A log message from the node.

    • Nested Class Summary

      Nested Classes 
      Modifier and Type Class Description
      public class Info.ConnectionsMet

      All the required connections have been met. This is subject to change.

      public class Info.SuccessfulHandshake

      The node was able to successfully connect to a remote peer.

      public final class Info.Progress

      A percentage value of filters that have been scanned.

      public final class Info.BlockReceived

      A relevant block was downloaded from a peer.

      public class Info.Companion