Package 

Enum Network

  • All Implemented Interfaces:
    java.io.Serializable , kotlin.Comparable

    
    public enum Network
    extends Enum<Network>
                        

    The cryptocurrency network to act on.

    This is an exhaustive enum, meaning that we cannot add any future networks without defining a new, incompatible version of this type. If you are using this type directly and wish to support the new network, this will be a breaking change to your APIs and likely require changes in your code.

    If you are concerned about forward compatibility, consider using T: Into<Params> instead of this type as a parameter to functions in your public API, or directly using the Params type.

    • Nested Class Summary

      Nested Classes 
      Modifier and Type Class Description
      public class Network.Companion
    • Method Summary

      Modifier and Type Method Description
      final String getName()
      final Integer getOrdinal()
      • Methods inherited from class java.lang.Object

        clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait