Package 

Class NodeInfo

  • All Implemented Interfaces:
    java.lang.AutoCloseable , org.bitcoindevkit.Disposable , org.bitcoindevkit.NodeInfoInterface

    
    public class NodeInfo
     implements Disposable, AutoCloseable, NodeInfoInterface
                        

    Represents the node information in taproot tree. In contrast to TapTree, this is allowed to have hidden leaves as children.

    Helper type used in merkle tree construction allowing one to build sparse merkle trees. The node represents part of the tree that has information about all of its descendants. See how TaprootBuilder works for more details. You can use TaprootSpendInfo::from_node_info to a get a TaprootSpendInfo from the merkle root NodeInfo.

    • Method Summary

      Modifier and Type Method Description
      Unit destroy()
      Unit close()
      List<LeafNode> leafNodes() Creates an iterator over all leaves (including hidden leaves) in the tree.
      String nodeHash() Returns the root TapNodeHash of this node info.
      String toString()
      • Methods inherited from class java.lang.Object

        clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait