-
- All Implemented Interfaces:
-
org.bitcoindevkit.Disposable
public final class Output implements Disposable
A key-value map for an output of the corresponding index in the unsigned transaction.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public classOutput.Companion
-
Field Summary
Fields Modifier and Type Field Description private ScriptredeemScriptprivate ScriptwitnessScriptprivate Map<String, KeySource>bip32Derivationprivate StringtapInternalKeyprivate TapTreetapTreeprivate Map<String, TapKeyOrigin>tapKeyOriginsprivate Map<ProprietaryKey, ByteArray>proprietaryprivate Map<Key, ByteArray>unknown
-
Method Summary
Modifier and Type Method Description final ScriptgetRedeemScript()The redeem script for this output. final UnitsetRedeemScript(Script redeemScript)The redeem script for this output. final ScriptgetWitnessScript()The witness script for this output. final UnitsetWitnessScript(Script witnessScript)The witness script for this output. final Map<String, KeySource>getBip32Derivation()Map of public keys needed to spend this output to their corresponding master key fingerprints and derivation paths. final UnitsetBip32Derivation(Map<String, KeySource> bip32Derivation)Map of public keys needed to spend this output to their corresponding master key fingerprints and derivation paths. final StringgetTapInternalKey()Taproot Internal key. final UnitsetTapInternalKey(String tapInternalKey)Taproot Internal key. final TapTreegetTapTree()Taproot Output tree (structured record). final UnitsetTapTree(TapTree tapTree)Taproot Output tree (structured record). final Map<String, TapKeyOrigin>getTapKeyOrigins()Map of tap root x only keys to origin info and leaf hashes contained in it. final UnitsetTapKeyOrigins(Map<String, TapKeyOrigin> tapKeyOrigins)Map of tap root x only keys to origin info and leaf hashes contained in it. final Map<ProprietaryKey, ByteArray>getProprietary()Proprietary key-value pairs for this output. final UnitsetProprietary(Map<ProprietaryKey, ByteArray> proprietary)Proprietary key-value pairs for this output. final Map<Key, ByteArray>getUnknown()Unknown key-value pairs for this output. final UnitsetUnknown(Map<Key, ByteArray> unknown)Unknown key-value pairs for this output. Unitdestroy()-
-
Method Detail
-
getRedeemScript
final Script getRedeemScript()
The redeem script for this output.
-
setRedeemScript
final Unit setRedeemScript(Script redeemScript)
The redeem script for this output.
-
getWitnessScript
final Script getWitnessScript()
The witness script for this output.
-
setWitnessScript
final Unit setWitnessScript(Script witnessScript)
The witness script for this output.
-
getBip32Derivation
final Map<String, KeySource> getBip32Derivation()
Map of public keys needed to spend this output to their corresponding master key fingerprints and derivation paths.
-
setBip32Derivation
final Unit setBip32Derivation(Map<String, KeySource> bip32Derivation)
Map of public keys needed to spend this output to their corresponding master key fingerprints and derivation paths.
-
getTapInternalKey
final String getTapInternalKey()
Taproot Internal key.
-
setTapInternalKey
final Unit setTapInternalKey(String tapInternalKey)
Taproot Internal key.
-
getTapTree
final TapTree getTapTree()
Taproot Output tree (structured record).
-
setTapTree
final Unit setTapTree(TapTree tapTree)
Taproot Output tree (structured record).
-
getTapKeyOrigins
final Map<String, TapKeyOrigin> getTapKeyOrigins()
Map of tap root x only keys to origin info and leaf hashes contained in it.
-
setTapKeyOrigins
final Unit setTapKeyOrigins(Map<String, TapKeyOrigin> tapKeyOrigins)
Map of tap root x only keys to origin info and leaf hashes contained in it.
-
getProprietary
final Map<ProprietaryKey, ByteArray> getProprietary()
Proprietary key-value pairs for this output.
-
setProprietary
final Unit setProprietary(Map<ProprietaryKey, ByteArray> proprietary)
Proprietary key-value pairs for this output.
-
getUnknown
final Map<Key, ByteArray> getUnknown()
Unknown key-value pairs for this output.
-
setUnknown
final Unit setUnknown(Map<Key, ByteArray> unknown)
Unknown key-value pairs for this output.
-
-
-
-