Package 

Class PersistenceImpl

  • All Implemented Interfaces:
    java.lang.AutoCloseable , org.bitcoindevkit.Disposable , org.bitcoindevkit.Persistence

    
    public class PersistenceImpl
     implements Disposable, AutoCloseable, Persistence
                        

    Definition of a wallet persistence implementation.

    • Constructor Summary

      Constructors 
      Constructor Description
      PersistenceImpl(Pointer pointer)
      PersistenceImpl(NoPointer noPointer) This constructor can be used to instantiate a fake object.
    • Method Summary

      Modifier and Type Method Description
      Unit destroy()
      Unit close()
      final Pointer uniffiClonePointer()
      ChangeSet initialize() Initialize the total aggregate ChangeSet for the underlying wallet.
      Unit persist(ChangeSet changeset) Persist a ChangeSet to the total aggregate changeset of the wallet.
      • Methods inherited from class java.lang.Object

        clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
    • Constructor Detail

      • PersistenceImpl

        PersistenceImpl(Pointer pointer)
      • PersistenceImpl

        PersistenceImpl(NoPointer noPointer)
        This constructor can be used to instantiate a fake object.