Package 

Class ProprietaryKey

    • Method Summary

      Modifier and Type Method Description
      final ByteArray getPrefix() Proprietary type prefix used for grouping together keys under some application and avoid namespace collision
      final Unit setPrefix(ByteArray prefix) Proprietary type prefix used for grouping together keys under some application and avoid namespace collision
      final UByte getSubtype() Custom proprietary subtype
      final Unit setSubtype(UByte subtype) Custom proprietary subtype
      final ByteArray getKey() Additional key bytes (like serialized public key data etc)
      final Unit setKey(ByteArray key) Additional key bytes (like serialized public key data etc)
      • Methods inherited from class java.lang.Object

        clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
    • Method Detail

      • getPrefix

         final ByteArray getPrefix()

        Proprietary type prefix used for grouping together keys under some application and avoid namespace collision

      • setPrefix

         final Unit setPrefix(ByteArray prefix)

        Proprietary type prefix used for grouping together keys under some application and avoid namespace collision

      • getKey

         final ByteArray getKey()

        Additional key bytes (like serialized public key data etc)

      • setKey

         final Unit setKey(ByteArray key)

        Additional key bytes (like serialized public key data etc)