Package 

Class Script

  • All Implemented Interfaces:
    java.lang.AutoCloseable , org.bitcoindevkit.Disposable , org.bitcoindevkit.ScriptInterface

    
    public class Script
     implements Disposable, AutoCloseable, ScriptInterface
                        

    A bitcoin script: https://en.bitcoin.it/wiki/Script

    • Nested Class Summary

      Nested Classes 
      Modifier and Type Class Description
      public class Script.Companion
    • Constructor Summary

      Constructors 
      Constructor Description
      Script(Pointer pointer)
      Script(NoPointer noPointer) This constructor can be used to instantiate a fake object.
      Script(ByteArray rawOutputScript) Interpret an array of bytes as a bitcoin script.
    • Constructor Detail

      • Script

        Script(Pointer pointer)
      • Script

        Script(NoPointer noPointer)
        This constructor can be used to instantiate a fake object.
      • Script

        Script(ByteArray rawOutputScript)
        Interpret an array of bytes as a bitcoin script.