Package 

Class SentAndReceivedValues

  • All Implemented Interfaces:
    org.bitcoindevkit.Disposable

    
    public final class SentAndReceivedValues
     implements Disposable
                        

    The total value sent and received.

    • Method Summary

      Modifier and Type Method Description
      final Amount getSent() Amount sent in the transaction.
      final Unit setSent(Amount sent) Amount sent in the transaction.
      final Amount getReceived() The amount received in the transaction, possibly as a change output(s).
      final Unit setReceived(Amount received) The amount received in the transaction, possibly as a change output(s).
      Unit destroy()
      • Methods inherited from class java.lang.Object

        clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
    • Constructor Detail

      • SentAndReceivedValues

        SentAndReceivedValues(Amount sent, Amount received)