-
- All Implemented Interfaces:
-
java.lang.AutoCloseable,org.bitcoindevkit.Disposable,org.bitcoindevkit.SyncScriptInspector
public class SyncScriptInspectorImpl implements Disposable, AutoCloseable, SyncScriptInspector
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public classSyncScriptInspectorImpl.Companion
-
Constructor Summary
Constructors Constructor Description SyncScriptInspectorImpl(Pointer pointer)SyncScriptInspectorImpl(NoPointer noPointer)This constructor can be used to instantiate a fake object.
-