Package 

Class TapScriptSigKey

    • Method Summary

      Modifier and Type Method Description
      final String getXonlyPubkey() An x-only public key, used for verification of Taproot signatures and serialized according to BIP-340.
      final Unit setXonlyPubkey(String xonlyPubkey) An x-only public key, used for verification of Taproot signatures and serialized according to BIP-340.
      final String getTapLeafHash() Taproot-tagged hash with tag "TapLeaf".
      final Unit setTapLeafHash(String tapLeafHash) Taproot-tagged hash with tag "TapLeaf".
      • Methods inherited from class java.lang.Object

        clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
    • Constructor Detail

      • TapScriptSigKey

        TapScriptSigKey(String xonlyPubkey, String tapLeafHash)
    • Method Detail

      • getXonlyPubkey

         final String getXonlyPubkey()

        An x-only public key, used for verification of Taproot signatures and serialized according to BIP-340.

      • setXonlyPubkey

         final Unit setXonlyPubkey(String xonlyPubkey)

        An x-only public key, used for verification of Taproot signatures and serialized according to BIP-340.

      • getTapLeafHash

         final String getTapLeafHash()

        Taproot-tagged hash with tag "TapLeaf". This is used for computing tapscript script spend hash.

      • setTapLeafHash

         final Unit setTapLeafHash(String tapLeafHash)

        Taproot-tagged hash with tag "TapLeaf". This is used for computing tapscript script spend hash.