Package 

Class TapTree

  • All Implemented Interfaces:
    java.lang.AutoCloseable , org.bitcoindevkit.Disposable , org.bitcoindevkit.TapTreeInterface

    
    public class TapTree
     implements Disposable, AutoCloseable, TapTreeInterface
                        

    Taproot Tree representing a complete binary tree without any hidden nodes.

    This is in contrast to NodeInfo, which allows hidden nodes. The implementations for Eq, PartialEq and Hash compare the merkle root of the tree

    • Method Summary

      Modifier and Type Method Description
      Unit destroy()
      Unit close()
      NodeInfo nodeInfo() Gets the reference to inner NodeInfo of this tree root.
      String rootHash() Returns the root TapNodeHash of this tree.
      String toString()
      • Methods inherited from class java.lang.Object

        clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait