Package 

Interface TapTreeInterface


  • 
    public interface TapTreeInterface
    
                        

    Taproot Tree representing a complete binary tree without any hidden nodes.

    This is in contrast to NodeInfo, which allows hidden nodes. The implementations for Eq, PartialEq and Hash compare the merkle root of the tree

    • Method Summary

      Modifier and Type Method Description
      abstract NodeInfo nodeInfo() Gets the reference to inner NodeInfo of this tree root.
      abstract String rootHash() Returns the root TapNodeHash of this tree.
      • Methods inherited from class java.lang.Object

        clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
    • Method Detail

      • nodeInfo

         abstract NodeInfo nodeInfo()

        Gets the reference to inner NodeInfo of this tree root.

      • rootHash

         abstract String rootHash()

        Returns the root TapNodeHash of this tree.