-
- All Implemented Interfaces:
-
org.bitcoindevkit.Disposable
public final class TxIn implements Disposable
A transcation input.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public classTxIn.Companion
-
Method Summary
Modifier and Type Method Description final OutPointgetPreviousOutput()A pointer to the previous output this input spends from. final UnitsetPreviousOutput(OutPoint previousOutput)A pointer to the previous output this input spends from. final ScriptgetScriptSig()The script corresponding to the scriptPubKey, empty in SegWit transactions.final UnitsetScriptSig(Script scriptSig)The script corresponding to the scriptPubKey, empty in SegWit transactions.final UIntgetSequence()https://bitcoin.stackexchange. final UnitsetSequence(UInt sequence)https://bitcoin.stackexchange. final List<ByteArray>getWitness()A proof for the script that authorizes the spend of the output. final UnitsetWitness(List<ByteArray> witness)A proof for the script that authorizes the spend of the output. Unitdestroy()-
-
Method Detail
-
getPreviousOutput
final OutPoint getPreviousOutput()
A pointer to the previous output this input spends from.
-
setPreviousOutput
final Unit setPreviousOutput(OutPoint previousOutput)
A pointer to the previous output this input spends from.
-
getScriptSig
final Script getScriptSig()
The script corresponding to the
scriptPubKey, empty in SegWit transactions.
-
setScriptSig
final Unit setScriptSig(Script scriptSig)
The script corresponding to the
scriptPubKey, empty in SegWit transactions.
-
getSequence
final UInt getSequence()
https://bitcoin.stackexchange.com/questions/87372/what-does-the-sequence-in-a-transaction-input-mean
-
setSequence
final Unit setSequence(UInt sequence)
https://bitcoin.stackexchange.com/questions/87372/what-does-the-sequence-in-a-transaction-input-mean
-
getWitness
final List<ByteArray> getWitness()
A proof for the script that authorizes the spend of the output.
-
setWitness
final Unit setWitness(List<ByteArray> witness)
A proof for the script that authorizes the spend of the output.
-
-
-
-