Package 

Class TxOut

  • All Implemented Interfaces:
    org.bitcoindevkit.Disposable

    
    public final class TxOut
     implements Disposable
                        

    Bitcoin transaction output.

    Defines new coins to be created as a result of the transaction, along with spending conditions ("script", aka "output script"), which an input spending it must satisfy.

    An output that is not yet spent by an input is called Unspent Transaction Output ("UTXO").

    • Nested Class Summary

      Nested Classes 
      Modifier and Type Class Description
      public class TxOut.Companion
    • Constructor Summary

      Constructors 
      Constructor Description
      TxOut(Amount value, Script scriptPubkey)
    • Method Summary

      Modifier and Type Method Description
      final Amount getValue() The value of the output, in satoshis.
      final Unit setValue(Amount value) The value of the output, in satoshis.
      final Script getScriptPubkey() The script which must be satisfied for the output to be spent.
      final Unit setScriptPubkey(Script scriptPubkey) The script which must be satisfied for the output to be spent.
      Unit destroy()
      • Methods inherited from class java.lang.Object

        clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait