-
- All Implemented Interfaces:
-
org.bitcoindevkit.Disposable
public final class TxStatus implements Disposable
Transaction confirmation metadata.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public classTxStatus.Companion
-
Method Summary
Modifier and Type Method Description final BooleangetConfirmed()Is the transaction in a block. final UnitsetConfirmed(Boolean confirmed)Is the transaction in a block. final UIntgetBlockHeight()Height of the block this transaction was included. final UnitsetBlockHeight(UInt blockHeight)Height of the block this transaction was included. final BlockHashgetBlockHash()Hash of the block. final UnitsetBlockHash(BlockHash blockHash)Hash of the block. final ULonggetBlockTime()The time shown in the block, not necessarily the same time as when the block was found. final UnitsetBlockTime(ULong blockTime)The time shown in the block, not necessarily the same time as when the block was found. Unitdestroy()-
-
Method Detail
-
getConfirmed
final Boolean getConfirmed()
Is the transaction in a block.
-
setConfirmed
final Unit setConfirmed(Boolean confirmed)
Is the transaction in a block.
-
getBlockHeight
final UInt getBlockHeight()
Height of the block this transaction was included.
-
setBlockHeight
final Unit setBlockHeight(UInt blockHeight)
Height of the block this transaction was included.
-
getBlockHash
final BlockHash getBlockHash()
Hash of the block.
-
setBlockHash
final Unit setBlockHash(BlockHash blockHash)
Hash of the block.
-
getBlockTime
final ULong getBlockTime()
The time shown in the block, not necessarily the same time as when the block was found.
-
setBlockTime
final Unit setBlockTime(ULong blockTime)
The time shown in the block, not necessarily the same time as when the block was found.
-
-
-
-