-
public class WarningWarnings a node may issue while running.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public classWarning.NeedConnectionsThe node is looking for connections to peers.
public classWarning.PeerTimedOutA connection to a peer timed out.
public classWarning.CouldNotConnectThe node was unable to connect to a peer in the database.
public classWarning.NoCompactFiltersA connection was maintained, but the peer does not signal for compact block filers.
public classWarning.PotentialStaleTipThe node has been waiting for new inv and will find new peers to avoid block withholding.
public classWarning.UnsolicitedMessageA peer sent us a peer-to-peer message the node did not request.
public final classWarning.TransactionRejectedA transaction got rejected, likely for being an insufficient fee or non-standard transaction.
public classWarning.EvaluatingForkThe peer sent us a potential fork.
public final classWarning.UnexpectedSyncErrorAn unexpected error occurred processing a peer-to-peer message.
public classWarning.RequestFailedThe node failed to respond to a message sent from the client.
public classWarning.Companion
-