| InternalException | |
| Address | A bitcoin address |
| Amount | The Amount type can be used to express Bitcoin amounts that support arithmetic and conversion to various denominations. |
| BlockHash | A bitcoin Block hash |
| BumpFeeTxBuilder | A BumpFeeTxBuilder is created by calling build_fee_bump on a wallet. |
| CbfBuilder | Build a BIP 157/158 light client to fetch transactions for a Wallet. |
| CbfClient | A `CbfClient` handles wallet updates from a `CbfNode`. |
| CbfNode | A `CbfNode` gathers transactions for a `Wallet`. |
| ChangeSet | |
| DerivationPath | A BIP-32 derivation path. |
| Descriptor | An expression of how to derive output scripts: https://github.com/bitcoin/bitcoin/blob/master/doc/descriptors. |
| DescriptorId | A collision-proof unique identifier for a descriptor. |
| DescriptorPublicKey | A descriptor public key. |
| DescriptorSecretKey | A descriptor containing secret data. |
| ElectrumClient | Wrapper around an electrum_client::ElectrumApi which includes an internal in-memory transaction cache to avoid re-fetching already downloaded transactions. |
| EsploraClient | Wrapper around an esplora_client::BlockingClient which includes an internal in-memory transaction cache to avoid re-fetching already downloaded transactions. |
| FeeRate | Represents fee rate. |
| FullScanRequest | |
| FullScanRequestBuilder | |
| FullScanScriptInspectorImpl | |
| HashableOutPoint | An `OutPoint` used as a key in a hash map. |
| IpAddress | An IP address to connect to over TCP. |
| LeafNode | Store information about taproot leaf node. |
| Mnemonic | A mnemonic seed phrase to recover a BIP-32 wallet. |
| NodeInfo | Represents the node information in taproot tree. |
| PersistenceImpl | Definition of a wallet persistence implementation. |
| Persister | Wallet backend implementations. |
| Policy | Descriptor spending policy |
| Psbt | A Partially Signed Transaction. |
| Script | A bitcoin script: https://en.bitcoin. |
| SyncRequest | |
| SyncRequestBuilder | |
| SyncScriptInspectorImpl | |
| TapTree | Taproot Tree representing a complete binary tree without any hidden nodes. |
| Transaction | Bitcoin transaction. |
| TxBuilder | A TxBuilder is created by calling build_tx on a wallet. |
| TxMerkleNode | The merkle root of the merkle tree corresponding to a block's transactions. |
| Txid | A bitcoin transaction identifier |
| Update | An update for a wallet containing chain, descriptor index, and transaction data. |
| Wallet | A Bitcoin wallet. |
| Wtxid | A bitcoin transaction identifier, including witness data. |
| AddressInfo | A derived address and the index it was found at. |
| Anchor | |
| Balance | Balance, differentiated into various categories. |
| Block | Bitcoin block. |
| BlockId | A reference to a block in the canonical chain. |
| CanonicalTx | A transaction that is deemed to be part of the canonical history. |
| CbfComponents | Receive a `CbfClient` and `CbfNode`. |
| ChainChange | The hash added or removed at the given height. |
| Condition | An extra condition that must be satisfied but that is out of control of the user |
| ConfirmationBlockTime | Represents the confirmation block and time of a transaction. |
| Conflict | Represent a conflict in a replacement transaction. |
| ControlBlock | |
| EvictedTx | This type replaces the Rust tuple (txid, evicted_at) used in the Wallet::apply_evicted_txsmethod, where evicted_atis the timestamp of when the transaction txid` was evicted from the mempool. |
| FinalizedPsbtResult | |
| Header | Bitcoin block header. |
| HeaderNotification | Notification of a new block header. |
| IndexerChangeSet | Mapping of descriptors to their last revealed index. |
| Input | A key-value map for an input of the corresponding index in the unsigned transaction. |
| Key | |
| KeySource | |
| KeychainAndIndex | The keychain kind and the index in that keychain. |
| LocalChainChangeSet | Changes to the local chain |
| LocalOutput | An unspent output owned by a `Wallet`. |
| MerkleProof | |
| OutPoint | A reference to an unspent output by TXID and output index. |
| Output | A key-value map for an output of the corresponding index in the unsigned transaction. |
| OutputStatus | |
| Peer | A peer to connect to over the Bitcoin peer-to-peer network. |
| ProprietaryKey | |
| ScriptAmount | A bitcoin script and associated amount. |
| SentAndReceivedValues | The total value sent and received. |
| ServerFeaturesRes | Response to an ElectrumClient.server_features request. |
| SignOptions | Options for a software signer. |
| Socks5Proxy | A proxy to route network traffic, most likely through a Tor daemon. |
| TapKeyOrigin | |
| TapScriptEntry | |
| TapScriptSigKey | |
| Tx | Bitcoin transaction metadata. |
| TxDetails | |
| TxGraphChangeSet | |
| TxIn | A transcation input. |
| TxOut | Bitcoin transaction output. |
| TxStatus | Transaction confirmation metadata. |
| UnconfirmedTx | This type replaces the Rust tuple (tx, last_seen) used in the Wallet::apply_unconfirmed_txsmethod, where last_seenis the timestamp of when the transaction tx` was last seen in the mempool. |
| WitnessProgram | The version and program of a Segwit address. |
| InvalidTxid | |
| InvalidOutpoint | |
| MissingUtxo | |
| InputConversionException | |
| AddForeignUtxoException | |
| P2pkh | Legacy. |
| P2sh | Wrapped Segwit |
| Segwit | Segwit |
| AddressData | The type of address. |
| Base58 | |
| Bech32 | |
| WitnessVersion | |
| WitnessProgram | |
| UnknownHrp | |
| LegacyAddressTooLong | |
| InvalidBase58PayloadLength | |
| InvalidLegacyPrefix | |
| NetworkValidation | |
| OtherAddressParseErr | |
| AddressParseException | |
| CannotDeriveFromHardenedKey | |
| Secp256k1 | |
| InvalidChildNumber | |
| InvalidChildNumberFormat | |
| InvalidDerivationPathFormat | |
| UnknownVersion | |
| WrongExtendedKeyLength | |
| Base58 | |
| Hex | |
| InvalidPublicKeyHexLength | |
| UnknownException | |
| Bip32Exception | |
| BadWordCount | |
| UnknownWord | |
| BadEntropyBitCount | |
| InvalidChecksum | |
| AmbiguousLanguages | |
| Bip39Exception | |
| MissingTxOut | |
| NegativeFee | |
| CalculateFeeException | |
| Include | |
| CannotConnectException | |
| NodeStopped | |
| CbfException | |
| Confirmed | The chain data is confirmed as it is anchored in the best chain by A. |
| Unconfirmed | The transaction was last seen in the mempool at this timestamp. |
| ChainPosition | Represents the observed position of some chain data. |
| Normal | Non-hardened key |
| Hardened | Hardened key |
| ChildNumber | A child number in a derivation path |
| Descriptor | |
| Policy | |
| SpendingPolicyRequired | |
| Version0 | |
| Version1Csv | |
| LockTime | |
| RbfSequenceCsv | |
| FeeTooLow | |
| FeeRateTooLow | |
| NoUtxosSelected | |
| OutputBelowDustLimit | |
| ChangePolicyDescriptor | |
| CoinSelection | |
| InsufficientFunds | |
| NoRecipients | |
| Psbt | |
| MissingKeyOrigin | |
| UnknownUtxo | |
| MissingNonWitnessUtxo | |
| MiniscriptPsbt | |
| PushBytesException | |
| LockTimeConversionException | |
| CreateTxException | |
| Persist | |
| DataAlreadyExists | |
| Descriptor | |
| CreateWithPersistException | |
| InvalidHdKeyPath | |
| InvalidDescriptorChecksum | |
| HardenedDerivationXpub | |
| MultiPath | |
| Key | |
| Policy | |
| InvalidDescriptorCharacter | |
| Bip32 | |
| Base58 | |
| Pk | |
| Miniscript | |
| Hex | |
| ExternalAndInternalAreTheSame | |
| DescriptorException | |
| Parse | |
| InvalidKeyType | |
| Bip32 | |
| DescriptorKeyException | |
| IoException | |
| Json | |
| Hex | |
| Protocol | |
| Bitcoin | |
| AlreadySubscribed | |
| NotSubscribed | |
| InvalidResponse | |
| Message | |
| InvalidDnsNameException | |
| MissingDomain | |
| AllAttemptsErrored | |
| SharedIoException | |
| CouldntLockReader | |
| Mpsc | |
| CouldNotCreateConnection | |
| RequestAlreadyConsumed | |
| ElectrumException | |
| Minreq | |
| HttpResponse | |
| Parsing | |
| StatusCode | |
| BitcoinEncoding | |
| HexToArray | |
| HexToBytes | |
| TransactionNotFound | |
| HeaderHeightNotFound | |
| HeaderHashNotFound | |
| InvalidHttpHeaderName | |
| InvalidHttpHeaderValue | |
| RequestAlreadyConsumed | |
| InvalidResponse | |
| EsploraException | |
| AbsurdFeeRate | |
| MissingInputValue | |
| SendingTooMuch | |
| OtherExtractTxErr | |
| ExtractTxException | |
| ArithmeticOverflow | |
| FeeRateException | |
| UnrecognizedScript | |
| WitnessProgram | |
| WitnessVersion | |
| OtherFromScriptErr | |
| FromScriptException | |
| InvalidHash | |
| InvalidHexString | |
| HashParseException | |
| Progress | A percentage value of filters that have been scanned. |
| BlockReceived | A relevant block was downloaded from a peer. |
| Info | A log message from the node. |
| Persist | |
| InvalidChangeSet | |
| CouldNotLoad | |
| LoadWithPersistException | |
| Blocks | |
| Seconds | |
| LockTime | |
| AbsoluteLockTime | |
| AddrException | |
| AddrP2shException | |
| AnalysisException | |
| AtOutsideOr | |
| BadDescriptor | |
| BareDescriptorAddr | |
| CmsTooManyKeys | |
| ContextException | |
| CouldNotSatisfy | |
| ExpectedChar | |
| ImpossibleSatisfaction | |
| InvalidOpcode | |
| InvalidPush | |
| LiftException | |
| MaxRecursiveDepthExceeded | |
| MissingSig | |
| MultiATooManyKeys | |
| MultiColon | |
| MultipathDescLenMismatch | |
| NonMinimalVerify | |
| NonStandardBareScript | |
| NonTopLevel | |
| ParseThreshold | |
| PolicyException | |
| PubKeyCtxException | |
| RelativeLockTime | |
| Script | |
| Secp | |
| Threshold | |
| TrNoScriptCode | |
| Trailing | |
| TypeCheck | |
| Unexpected | |
| UnexpectedStart | |
| UnknownWrapper | |
| Unprintable | |
| MiniscriptException | |
| OutOfRange | |
| TooPrecise | |
| MissingDigits | |
| InputTooLarge | |
| InvalidCharacter | |
| OtherParseAmountErr | |
| ParseAmountException | |
| Reason | |
| PersistenceException | |
| Pubkey | |
| XOnlyPubkey | |
| Fingerprint | |
| PkOrF | |
| InvalidMagic | |
| MissingUtxo | |
| InvalidSeparator | |
| PsbtUtxoOutOfBounds | |
| InvalidKey | |
| InvalidProprietaryKey | |
| DuplicateKey | |
| UnsignedTxHasScriptSigs | |
| UnsignedTxHasScriptWitnesses | |
| MustHaveUnsignedTx | |
| NoMorePairs | |
| UnexpectedUnsignedTx | |
| NonStandardSighashType | |
| InvalidHash | |
| InvalidPreimageHashPair | |
| CombineInconsistentKeySources | |
| ConsensusEncoding | |
| NegativeFee | |
| FeeOverflow | |
| InvalidPublicKey | |
| InvalidSecp256k1PublicKey | |
| InvalidXOnlyPublicKey | |
| InvalidEcdsaSignature | |
| InvalidTaprootSignature | |
| InvalidControlBlock | |
| InvalidLeafVersion | |
| Taproot | |
| TapTree | |
| XPubKey | |
| Version | |
| PartialDataConsumption | |
| Io | |
| OtherPsbtErr | |
| PsbtException | |
| InputException | |
| WrongInputCount | |
| InputIdxOutofBounds | |
| PsbtFinalizeException | |
| PsbtEncoding | |
| Base64Encoding | |
| PsbtParseException | |
| Other | |
| RecoveryPoint | |
| RequestAlreadyConsumed | |
| RequestBuilderException | |
| Partial | |
| PartialComplete | |
| Complete | |
| None | |
| Satisfaction | |
| EcdsaSignature | |
| SchnorrSignature | |
| Sha256Preimage | |
| Hash256Preimage | |
| Ripemd160Preimage | |
| Hash160Preimage | |
| AbsoluteTimelock | |
| RelativeTimelock | |
| Multisig | |
| Thresh | |
| SatisfiableItem | |
| Recovery | Recover an existing wallet by scanning from the specified height. |
| ScanType | Sync a wallet from the last known block hash or recover a wallet from a specified recovery point. |
| MissingKey | |
| InvalidKey | |
| UserCanceled | |
| InputIndexOutOfRange | |
| MissingNonWitnessUtxo | |
| InvalidNonWitnessUtxo | |
| MissingWitnessUtxo | |
| MissingWitnessScript | |
| MissingHdKeypath | |
| NonStandardSighash | |
| InvalidSighash | |
| SighashP2wpkh | |
| SighashTaproot | |
| TxInputsIndexException | |
| MiniscriptPsbt | |
| External | |
| Psbt | |
| SignerException | |
| Io | |
| OversizedVectorAllocation | |
| InvalidChecksum | |
| NonMinimalVarInt | |
| ParseFailed | |
| UnsupportedSegwitFlag | |
| OtherTransactionErr | |
| TransactionException | |
| InvalidTxid | |
| TxidParseException | |
| ChainTipChanged | The latest chain tip known to the wallet changed. |
| TxConfirmed | A transaction is now confirmed. |
| TxUnconfirmed | A transaction is now unconfirmed. |
| TxReplaced | An unconfirmed transaction was replaced. |
| TxDropped | Unconfirmed transaction dropped. |
| WalletEvent | Events representing changes to wallet transactions. |
| TransactionRejected | A transaction got rejected, likely for being an insufficient fee or non-standard transaction. |
| UnexpectedSyncError | An unexpected error occurred processing a peer-to-peer message. |
| Warning | Warnings a node may issue while running. |