-
public interface CbfClientInterfaceA `CbfClient` handles wallet updates from a `CbfNode`.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public classCbfClientInterface.Companion
-
Method Summary
Modifier and Type Method Description abstract FeeRateaverageFeeRate(BlockHash blockhash)Fetch the average fee rate for a block by requesting it from a peer. abstract Wtxidbroadcast(Transaction transaction)Broadcast a transaction to the network, erroring if the node has stopped running. abstract Unitconnect(Peer peer)Add another `Peer` to attempt a connection with. abstract BooleanisRunning()Check if the node is still running in the background. abstract List<IpAddress>lookupHost(String hostname)Query a Bitcoin DNS seeder using the configured resolver. abstract FeeRateminBroadcastFeerate()The minimum fee rate required to broadcast a transcation to all connected peers. abstract InfonextInfo()Return the next available info message from a node. abstract WarningnextWarning()Return the next available warning message from a node. abstract Unitshutdown()Stop the `CbfNode`. abstract Updateupdate()Return an `Update`. -
-
Method Detail
-
averageFeeRate
abstract FeeRate averageFeeRate(BlockHash blockhash)
Fetch the average fee rate for a block by requesting it from a peer. Not recommend for resource-limited devices.
-
broadcast
abstract Wtxid broadcast(Transaction transaction)
Broadcast a transaction to the network, erroring if the node has stopped running.
-
lookupHost
abstract List<IpAddress> lookupHost(String hostname)
Query a Bitcoin DNS seeder using the configured resolver.
This is not a generic DNS implementation. Host names are prefixed with a
x849to filter for compact block filter nodes from the seeder. For exampledns.myseeder.comwill be queried asx849.dns.myseeder.com. This has no guarantee to return anyIpAddr.
-
minBroadcastFeerate
abstract FeeRate minBroadcastFeerate()
The minimum fee rate required to broadcast a transcation to all connected peers.
-
nextInfo
abstract Info nextInfo()
Return the next available info message from a node. If none is returned, the node has stopped.
-
nextWarning
abstract Warning nextWarning()
Return the next available warning message from a node. If none is returned, the node has stopped.
-
-
-
-