-
- All Implemented Interfaces:
-
java.lang.AutoCloseable,org.bitcoindevkit.DerivationPathInterface,org.bitcoindevkit.Disposable
public class DerivationPath implements Disposable, AutoCloseable, DerivationPathInterface
A BIP-32 derivation path.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public classDerivationPath.Companion
-
Constructor Summary
Constructors Constructor Description DerivationPath(Pointer pointer)DerivationPath(NoPointer noPointer)This constructor can be used to instantiate a fake object. DerivationPath(String path)Parse a string as a BIP-32 derivation path.
-
Method Summary
Modifier and Type Method Description Unitdestroy()Unitclose()final PointeruniffiClonePointer()BooleanisEmpty()Returns trueif the derivation path is emptyBooleanisMaster()Returns whether derivation path represents master key (i.e. ULonglen()Returns length of the derivation path StringtoString()-
-
Constructor Detail
-
DerivationPath
DerivationPath(Pointer pointer)
-
DerivationPath
DerivationPath(NoPointer noPointer)
This constructor can be used to instantiate a fake object.
-
DerivationPath
DerivationPath(String path)
Parse a string as a BIP-32 derivation path.
-
-
Method Detail
-
uniffiClonePointer
final Pointer uniffiClonePointer()
-
isMaster
Boolean isMaster()
Returns whether derivation path represents master key (i.e. it's length is empty). True for
mpath.
-
-
-
-