-
public interface DerivationPathInterfaceA BIP-32 derivation path.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public classDerivationPathInterface.Companion
-
Method Summary
Modifier and Type Method Description abstract DerivationPathchild(ChildNumber childNumber)Create a new DerivationPath that is a child of this one. abstract DerivationPathextend(DerivationPath other)Concatenate selfwithpathand return the resulting new path.abstract BooleanisEmpty()Returns trueif the derivation path is emptyabstract BooleanisMaster()Returns whether derivation path represents master key (i.e. abstract ULonglen()Returns length of the derivation path abstract List<UInt>toU32Vec()Returns the derivation path as a vector of u32 integers. -
-
Method Detail
-
child
abstract DerivationPath child(ChildNumber childNumber)
Create a new DerivationPath that is a child of this one.
-
extend
abstract DerivationPath extend(DerivationPath other)
Concatenate
selfwithpathand return the resulting new path.
-
isMaster
abstract Boolean isMaster()
Returns whether derivation path represents master key (i.e. it's length is empty). True for
mpath.
-
-
-
-