Package 

Class FeeRate

  • All Implemented Interfaces:
    java.lang.AutoCloseable , org.bitcoindevkit.Disposable , org.bitcoindevkit.FeeRateInterface

    
    public class FeeRate
     implements Disposable, AutoCloseable, FeeRateInterface
                        

    Represents fee rate.

    This is an integer type representing fee rate in sat/kwu. It provides protection against mixing up the types as well as basic formatting features.