Package 

Interface FeeRateInterface


  • 
    public interface FeeRateInterface
    
                        

    Represents fee rate.

    This is an integer type representing fee rate in sat/kwu. It provides protection against mixing up the types as well as basic formatting features.