-
public class InfoA log message from the node.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public classInfo.ConnectionsMetAll the required connections have been met. This is subject to change.
public classInfo.SuccessfulHandshakeThe node was able to successfully connect to a remote peer.
public final classInfo.ProgressA percentage value of filters that have been scanned.
public final classInfo.BlockReceivedA relevant block was downloaded from a peer.
public classInfo.Companion
-