-
- All Implemented Interfaces:
-
java.lang.AutoCloseable,org.bitcoindevkit.Disposable,org.bitcoindevkit.Persistence
public class PersistenceImpl implements Disposable, AutoCloseable, Persistence
Definition of a wallet persistence implementation.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public classPersistenceImpl.Companion
-
Constructor Summary
Constructors Constructor Description PersistenceImpl(Pointer pointer)PersistenceImpl(NoPointer noPointer)This constructor can be used to instantiate a fake object.
-
Method Summary
Modifier and Type Method Description Unitdestroy()Unitclose()final PointeruniffiClonePointer()ChangeSetinitialize()Initialize the total aggregate ChangeSetfor the underlying wallet.Unitpersist(ChangeSet changeset)Persist a ChangeSetto the total aggregate changeset of the wallet.-
-
Method Detail
-
uniffiClonePointer
final Pointer uniffiClonePointer()
-
initialize
ChangeSet initialize()
Initialize the total aggregate
ChangeSetfor the underlying wallet.
-
-
-
-