-
public final class ProprietaryKey
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public classProprietaryKey.Companion
-
Constructor Summary
Constructors Constructor Description ProprietaryKey(ByteArray prefix, UByte subtype, ByteArray key)
-
Method Summary
Modifier and Type Method Description final ByteArraygetPrefix()Proprietary type prefix used for grouping together keys under some application and avoid namespace collision final UnitsetPrefix(ByteArray prefix)Proprietary type prefix used for grouping together keys under some application and avoid namespace collision final UBytegetSubtype()Custom proprietary subtype final UnitsetSubtype(UByte subtype)Custom proprietary subtype final ByteArraygetKey()Additional key bytes (like serialized public key data etc) final UnitsetKey(ByteArray key)Additional key bytes (like serialized public key data etc) -
-
Method Detail
-
getPrefix
final ByteArray getPrefix()
Proprietary type prefix used for grouping together keys under some application and avoid namespace collision
-
setPrefix
final Unit setPrefix(ByteArray prefix)
Proprietary type prefix used for grouping together keys under some application and avoid namespace collision
-
getSubtype
final UByte getSubtype()
Custom proprietary subtype
-
setSubtype
final Unit setSubtype(UByte subtype)
Custom proprietary subtype
-
-
-
-