-
- All Implemented Interfaces:
-
org.bitcoindevkit.Disposable
public final class SentAndReceivedValues implements Disposable
The total value sent and received.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public classSentAndReceivedValues.Companion
-
Constructor Summary
Constructors Constructor Description SentAndReceivedValues(Amount sent, Amount received)
-
Method Summary
Modifier and Type Method Description final AmountgetSent()Amount sent in the transaction. final UnitsetSent(Amount sent)Amount sent in the transaction. final AmountgetReceived()The amount received in the transaction, possibly as a change output(s). final UnitsetReceived(Amount received)The amount received in the transaction, possibly as a change output(s). Unitdestroy()-
-
Method Detail
-
getReceived
final Amount getReceived()
The amount received in the transaction, possibly as a change output(s).
-
setReceived
final Unit setReceived(Amount received)
The amount received in the transaction, possibly as a change output(s).
-
-
-
-