-
public final class TapScriptSigKey
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public classTapScriptSigKey.Companion
-
Field Summary
Fields Modifier and Type Field Description private StringxonlyPubkeyprivate StringtapLeafHash
-
Constructor Summary
Constructors Constructor Description TapScriptSigKey(String xonlyPubkey, String tapLeafHash)
-
Method Summary
Modifier and Type Method Description final StringgetXonlyPubkey()An x-only public key, used for verification of Taproot signatures and serialized according to BIP-340. final UnitsetXonlyPubkey(String xonlyPubkey)An x-only public key, used for verification of Taproot signatures and serialized according to BIP-340. final StringgetTapLeafHash()Taproot-tagged hash with tag "TapLeaf". final UnitsetTapLeafHash(String tapLeafHash)Taproot-tagged hash with tag "TapLeaf". -
-
Method Detail
-
getXonlyPubkey
final String getXonlyPubkey()
An x-only public key, used for verification of Taproot signatures and serialized according to BIP-340.
-
setXonlyPubkey
final Unit setXonlyPubkey(String xonlyPubkey)
An x-only public key, used for verification of Taproot signatures and serialized according to BIP-340.
-
getTapLeafHash
final String getTapLeafHash()
Taproot-tagged hash with tag "TapLeaf". This is used for computing tapscript script spend hash.
-
setTapLeafHash
final Unit setTapLeafHash(String tapLeafHash)
Taproot-tagged hash with tag "TapLeaf". This is used for computing tapscript script spend hash.
-
-
-
-