-
- All Implemented Interfaces:
-
org.bitcoindevkit.Disposable
public final class TxOut implements Disposable
Bitcoin transaction output.
Defines new coins to be created as a result of the transaction, along with spending conditions ("script", aka "output script"), which an input spending it must satisfy.
An output that is not yet spent by an input is called Unspent Transaction Output ("UTXO").
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public classTxOut.Companion
-
Field Summary
Fields Modifier and Type Field Description private Amountvalueprivate ScriptscriptPubkey
-
Method Summary
Modifier and Type Method Description final AmountgetValue()The value of the output, in satoshis. final UnitsetValue(Amount value)The value of the output, in satoshis. final ScriptgetScriptPubkey()The script which must be satisfied for the output to be spent. final UnitsetScriptPubkey(Script scriptPubkey)The script which must be satisfied for the output to be spent. Unitdestroy()-
-
Method Detail
-
getScriptPubkey
final Script getScriptPubkey()
The script which must be satisfied for the output to be spent.
-
setScriptPubkey
final Unit setScriptPubkey(Script scriptPubkey)
The script which must be satisfied for the output to be spent.
-
-
-
-