-
- All Implemented Interfaces:
-
org.bitcoindevkit.Disposable
public class WalletEvent implements Disposable
Events representing changes to wallet transactions.
Returned after calling crate::wallet::Wallet::apply_update_events.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWalletEvent.ChainTipChangedThe latest chain tip known to the wallet changed.
public final classWalletEvent.TxConfirmedA transaction is now confirmed.
If the transaction was previously unconfirmed
old_block_timewill beNone.If a confirmed transaction is now re-confirmed in a new block
old_block_timewill contain the block id and the time it was previously confirmed. This can happen after a chain reorg.public final classWalletEvent.TxUnconfirmedA transaction is now unconfirmed.
If the transaction is first seen in the mempool
old_block_timewill beNone.If a previously confirmed transaction is now seen in the mempool
old_block_timewill contain the block id and the time it was previously confirmed. This can happen after a chain reorg.public final classWalletEvent.TxReplacedAn unconfirmed transaction was replaced.
This can happen after an RBF is broadcast or if a third party double spends an input of a received payment transaction before it is confirmed.
The conflicts field contains the txid and vin (in which it conflicts) of the conflicting transactions.
public final classWalletEvent.TxDroppedUnconfirmed transaction dropped.
The transaction was dropped from the local mempool. This is generally due to the fee rate being too low. The transaction can still reappear in the mempool in the future resulting in a `WalletEvent::TxUnconfirmed` event.
public classWalletEvent.Companion
-